@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://lxde.org/
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org/
  *
  * Copyright: 2014 LXQt team
  * Authors:
@@ -48,7 +48,7 @@ public:
     // virtual QPlatformMenuBar* createPlatformMenuBar() const;
 
     virtual bool usePlatformNativeDialog(DialogType type) const;
-    // virtual QPlatformDialogHelper *createPlatformDialogHelper(DialogType type) const;
+    virtual QPlatformDialogHelper *createPlatformDialogHelper(DialogType type) const;
 
     virtual const QPalette *palette(Palette type = SystemPalette) const;
 
@@ -78,11 +78,13 @@ public:
 
     // virtual QString standardButtonText(int button) const;
 
+public Q_SLOTS:
+    void lazyInit();
+
 private:
     void loadSettings();
 
 private Q_SLOTS:
-    void initWatch();
     void onSettingsChanged();
 
 private:
@@ -90,6 +92,7 @@ private:
     QString iconTheme_;
     Qt::ToolButtonStyle toolButtonStyle_;
     bool singleClickActivate_;
+    bool iconFollowColorScheme_;
 
     // other Qt settings
     // widget
